@@ -159,6 +159,34 @@ class TimeUtils:
 
         return start_date.strftime(format_str), end_date.strftime(format_str)
 
+    @staticmethod
+    def get_month_first_day(start_from: Optional[str] = None, format_str: str = '%Y-%m-%d') -> str:
+        """
+        获取某月的第一天
+
+        Args:
+            start_from: 参考日期，格式为'YYYY-MM-DD'，默认使用今天
+            format_str: 返回的日期格式，默认是'%Y-%m-%d'
+
+        Returns:
+            指定格式的某月第一天日期字符串
+
+        Example:
+            >>> get_month_first_day('2025-07-02')
+            '2025-07-01'
+        """
+        if start_from:
+            try:
+                base_date = datetime.strptime(start_from, '%Y-%m-%d')
+            except ValueError:
+                raise ValueError("start_from 格式必须是 'YYYY-MM-DD'")
+        else:
+            base_date = datetime.today()
+
+        # 获取当月第一天
+        first_day = base_date.replace(day=1)
+        return first_day.strftime(format_str)
+
     @staticmethod
     def get_past_nth_day(n: int, start_from: Optional[str] = None, format_str: str = '%Y-%m-%d') -> str:
         """
